@@ -2,7 +2,7 @@ package Bundle::Locale::CLDR::Outlyingoceania;
 
 use version;
 
-our $VERSION = version->declare('v0.40.1');
+our $VERSION = version->declare('v0.44.0');
 
 =head1 NAME
 
@@ -10,9 +10,9 @@ Bundle::Locale::CLDR::Outlyingoceania
 
 =head1 CONTENTS
 
-Locale::CLDR::Locales::En::Any::Dg 0.40.1
+Locale::CLDR::Locales::En::Latn::Dg 0.44.0
 
-Locale::CLDR::Locales::En::Any::001 0.40.1
+Locale::CLDR::Locales::En::Latn::001 0.44.0
 
 
 =cut
